@@ -1,9 +1,10 @@
 library(anonymizer)
 context("salt()")
 
-set.seed(1)
 test_that("Produces the correct output.", {
-  expect_equal(salt("a", .n_chars = 0), "a")
+  expect_equal(salt("a", .seed = 1, .n_chars = 0), "a")
+  expect_equal(salt("a", .seed = 1, .n_chars = 1), "gag")
+  expect_equal(salt("a", .seed = 2, .n_chars = 1), "eae")
 })
 
 test_that("Produces the correct output type.", {
